==> haskell-case-insensitive-1.2.1.0-203-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-case-insensitive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 case-insensitive
version:              1.2.1.0
visibility:           public
id:                   case-insensitive-1.2.1.0-BBCkGXkqh3nGRz3m4HFNUT
key:                  case-insensitive-1.2.1.0-BBCkGXkqh3nGRz3m4HFNUT
license:              BSD-3-Clause
copyright:            2011 Bas van Dijk
maintainer:           Bas van Dijk <v.dijk.bas@gmail.com>
author:               Bas van Dijk
homepage:             https://github.com/basvandijk/case-insensitive
synopsis:             Case insensitive string comparison
description:
    The module @Data.CaseInsensitive@ provides the '\''CI'\'' type
    constructor which can be parameterised by a string-like
    type like: '\''String'\'', '\''ByteString'\'', '\''Text'\'',
    etc.. Comparisons of values of the resulting type will be
    insensitive to cases.

category:             Data, Text
abi:                  a166db70476184eaa3597d0d8502eeee
exposed:              True
exposed-modules:      Data.CaseInsensitive Data.CaseInsensitive.Unsafe
hidden-modules:       Data.CaseInsensitive.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/case-insensitive-1.2.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/case-insensitive-1.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-case-insensitive
hs-libraries:         HScase-insensitive-1.2.1.0-BBCkGXkqh3nGRz3m4HFNUT
depends:
    base-4.16.4.0 bytestring-0.11.4.0 deepseq-1.4.6.1
    hashable-1.4.3.0-BWGpbAVaWdFEBuRI2sTyFL text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-case-insensitive/html/case-insensitive.haddock

haddock-html:         /usr/share/doc/haskell-case-insensitive/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-case-insensitive-1.2.1.0-205.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-case-insensitive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 case-insensitive
version:              1.2.1.0
visibility:           public
id:                   case-insensitive-1.2.1.0-6AqTtfG0yj5cd4BFV01sh
key:                  case-insensitive-1.2.1.0-6AqTtfG0yj5cd4BFV01sh
license:              BSD-3-Clause
copyright:            2011 Bas van Dijk
maintainer:           Bas van Dijk <v.dijk.bas@gmail.com>
author:               Bas van Dijk
homepage:             https://github.com/basvandijk/case-insensitive
synopsis:             Case insensitive string comparison
description:
    The module @Data.CaseInsensitive@ provides the '\''CI'\'' type
    constructor which can be parameterised by a string-like
    type like: '\''String'\'', '\''ByteString'\'', '\''Text'\'',
    etc.. Comparisons of values of the resulting type will be
    insensitive to cases.

category:             Data, Text
abi:                  1fcc650d77a78cfbd70ac1a84b6be1a7
exposed:              True
exposed-modules:      Data.CaseInsensitive Data.CaseInsensitive.Unsafe
hidden-modules:       Data.CaseInsensitive.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/case-insensitive-1.2.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/case-insensitive-1.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-case-insensitive
hs-libraries:         HScase-insensitive-1.2.1.0-6AqTtfG0yj5cd4BFV01sh
depends:
    base-4.16.4.0 bytestring-0.11.4.0 deepseq-1.4.6.1
    hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-case-insensitive/html/case-insensitive.haddock

haddock-html:         /usr/share/doc/haskell-case-insensitive/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
